*******************************************************************************************************************.
************************************************ Musterprogramm SPSS **************************************.
                               
*** Hinweis: Das Musterprogramm dient Ihnen zur Orientierung bei der Erstellung Ihres               ***.
*** Programmcodes. Das Ziel ist Ihre Outputfiles bestmglich fr die Geheimhaltungsprfung       ***.
*** aufzubereiten.                                                                                                                   ***.
*** Bitte beachten Sie: Dieses Musterprogramm enthlt keine statistikspezifischen                     ***.
*** Hilfestellungen zur Aufbereitung und Auswertung der von Ihnen beantragten Daten.                 ***.
                                                                                                                    
*******************************************************************************************************************.

*** Makros fr Pfade.
DEFINE !DATENPFAD   () '<Pfad wird im Forschungsdatenzentrum ergnzt>\' !ENDDEFINE.
DEFINE !OUTPUTPFAD () '<Pfad wird im Forschungsdatenzentrum ergnzt>\' !ENDDEFINE.

*** Makros fr Datei- und Outputnamen.
*** Dateiname und Outputname einfgen.
DEFINE !DATEINAME    () '<Dateiname.sav>' !ENDDEFINE.  
DEFINE !OUTPUTNAME () '<Outputname>'    !ENDDEFINE. 


*******************************************************************************************************************.
*** Aufzeichnung des Outputs starten.
OUTPUT NEW.


*******************************************************************************************************************.
*******************************************************************************************************************.
*******************************************************************************************************************.


*******************************************************************************************************************.
*******************************************************************************************************************.
*** Titel des Projekts:	   <Frauen und Arbeit in der Bundesrepublik>	
*** Datengrundlage:	      <Mikrozensus 2012>
***                                                                     
*** Dateiname des Programmcodes: <syntaxname.sps>               
*** erstellt:                                      <Datum>                           
*** von:                                           <Name>                            
*** E-Mail:                                       <E-Mail-Adresse>                  
*** Tel.:                                           <Telefonnummer>                   
***                                                                     
*** Dateiname des Output-Files:        <outputname.spv>                        
***                                                                    
***                                                                     
***  Grundriss des Programms:       <Programm zur Untersuchung von mehrfachen Personenstzen 
***                                                  (Check der Datenbasis), deskriptive Analysen.>                                                       
***   
***                                                                  
*** Verwendete Variablen:				          	
***	Originalvariablen:	      
***         <EF1:     Land der Bundesrepublik
***				       EF2:     Regierungsbezirk             
***				       EF3S:   systemfreie Auswahlbezirks-Nummer        
***				       EF4S:   systemfreie Lfd. Nr. des Haushalts       
***				       EF5S:   systemfreie Lfd. Nr. der Person im Haushalt
***				       EF25:   Lfd. Nr. d. Familie im Haushalt
***				       EF30:   Bevlkerung am Hauptwohnsitz
***           EF31:   Bevlkerung in Privathaushalten
***				       EF44:   Alter       
***				       EF46:   Geschlecht
***				       EF49:   Familienstand
***				       EF310: Hchster allgemeiner Schulabschluss
***           EF952: Standardhochrechnungsfaktor Jahr (Basis: Zensus 2011)>
***
*** Neu angelegte Variablen in dieser Syntax <syntaxname.sas>: 
*** 	       <verh:    dichotome Variable Verheiratet ja/nein
***          persnr:  Personennummer
*** 	        famnr:   Familiennummer 
*** 	        hhnr:     Haushaltsnummer 
*** 	        nrdiff:    Differenz Haushaltsnummer - Familiennummer
*** 	        piddiff:   Test einmalige Personennummer>
***
*** Anmerkung: Falls Variablen verwendet werden, die in einer vorherigen Syntax erstellt wurden, 
*** diese bitte in separaten Blcken auflisten.                
***
*** Gewichtungsvariable:	 <EF952>
***         
***                                                                     
*******************************************************************************************************************.
*******************************************************************************************************************.                                                            



*******************************************************************************************************************.
*** I. Datenaufbereitung
*******************************************************************************************************************.


*** a. Datensatz einlesen.
*** Speicher- und laufzeiteffizient die Auswahl der bentigten Variablen und Flle direkt vornehmen.

GET FILE = !DATENPFAD+!DATEINAME
/KEEP = EF1 EF2 EF3S EF4S EF5S EF25 EF30 EF31 EF44 EF46 EF49 EF310 EF952.  
EXECUTE.

*** Bevlkerung in Privathaushalten (EF31 = 1) am Ort der Hauptwohnung (EF30 < 3).

SELECT IF (EF31 = 1) & (EF30 < 3).
EXECUTE.


*** b. Generierung dichotome Variable verh, die angibt, ob Person verheiratet ist.

RECODE EF49 (2 = 1) (1,3,4,5,6,7 = 0) INTO verh.


*** c. Generierung Haushalts- und Familiennummer aus EF1, EF2, EF3S, EF4S, EF5S, EF25.
*** persnr: EF1-EF5S
*** hhnr:    EF1-EF4S
*** famnr:  EF1-EF4S + EF25.

COMPUTE persnr = (EF1*10000000000) + (EF2*1000000000) + (EF3S*100000) + (EF4S*1000) + (EF5S*10).
COMPUTE hhnr = (EF1*10000000000) + (EF2*1000000000) + (EF3S*100000) + (EF4S*1000) + 1.
COMPUTE famnr = (EF1*10000000000) + (EF2*1000000000) + (EF3S*100000) + (EF4S*1000) + (EF25*1). 
EXECUTE.


*** d. Vorbereitung Test: Haushaltsnummer ungleich Familiennummer.
*** Wenn Familiennummer (famnr) ungleich der Haushaltsnummer (personennr).
*** Dann Differenz Haushaltsnummer - Familiennummer (nrdiff) gleich 1.

COMPUTE nrdiff = 0.
EXECUTE.
DO IF famnr ~= hhnr.
 COMPUTE nrdiff = 1.
END IF.


*** e. Vorbereitung Test: mehrfache Personennummer.
*** Personennummer (persnr) gleich der des Vorgngers dann Personennummertest (piddiff) gleich 1.

SORT CASES BY persnr.
EXECUTE.
IF persnr EQ LAG(persnr) piddiff = 1.
EXECUTE.


*** f. Beschriftung der Variablen und Werte.

VARIABLE LABELS   verh          'Verheiratet'
                                 hhnr          'Haushaltsnummer'
                                 famnr        'Familiennummer'
                                 persnr       'Personennummer'
                                 nrdiff         'Differenz Haushaltsnummer - Familiennummer'
                                 piddiff        'Test einmalig Personennummer'.

VALUE LABELS         verh         1 'ja'
                                                0 'nein'.
VALUE LABELS         nrdiff        1 'Haushaltsnummer und Familiennummer unterschiedlich'
	                                               0 'Haushaltsnummer und Familiennummer gleich'. 	
VALUE LABELS        piddiff       1 'Personennummer mehrfach'
	                                               0 'Personennummer einfach'. 



*******************************************************************************************************************.
*** II. Datenauswertung
*******************************************************************************************************************.

*** Fr jedes erzeugte Ergebnis muss angegeben werden, ob es auf Geheimhaltung geprft und freigegeben werden soll 
*** oder ob es lediglich den Prfprozessen der FDZ dient. Diese Angabe kann pauschal in einem Kommentar erfolgen, 
*** beispielweise "Alle erzeugten Auswertungen werden bentigt." oder "Es werden ausschlielich gewichtete 
*** Auswertungen bentigt.", solange die Formulierung eindeutig ist.

*** Output Nr. 1: Haushaltsnummer ungleich Familiennummer.

TITLE "Output Nr. 1: Haushaltsnummer ungleich Familiennummer".
FREQUENCIES VAR = nrdiff.


*** Output Nr. 2: Mehrfache Personennummern.

TITLE "Output Nr. 2: Mehrfache Personennummer".	
FREQUENCIES VAR = piddiff.


*******************************************************************************************************************.
*** a. gewichtete Auswertungen ***

*** Fr die Geheimhaltungsprfung ist es erforderlich, bei gewichteten Ausgaben zustzlich
*** auch das ungewichtete Ergebnis mit ausgeben zu lassen.

*** Output Nr. 3a: ungewichtete Hufigkeit des Bundeslandes.

TITLE "Output Nr. 3: ungewichtete Hufigkeit des Bundeslandes".	
FREQUENCIES VAR = EF1.


*** Output Nr. 3b: gewichtete Hufigkeit des Bundeslandes.

WEIGHT BY EF952.
TITLE "Output Nr. 4: gewichtete Hufigkeit des Bundeslandes".	
FREQUENCIES VAR = EF1.
WEIGHT OFF.


*** Output Nr. 4a: ungewichtete Regression mit der abhngigen Variablen Alter (EF44) und 
***                       den beiden unabhngigen Variablen Geschlecht (EF46) und Verheiratet (verh)

REGRESSION VARIABLES EF46 verh
/DEPENDENT = EF44
/METHOD = STEPWISE.


*** Output Nr. 4b: gewichtete Regression mit der abhngigen Variablen Alter (EF44) und 
***                       den beiden unabhngigen Variablen Geschlecht (EF46) und Verheiratet (verh)

WEIGHT BY EF952.
REGRESSION VARIABLES EF46 verh
/DEPENDENT = EF44
/METHOD = STEPWISE.
WEIGHT OFF.


*******************************************************************************************************************.
*** b. Auswertungen mit Filterbedingungen ***

*** Restgren, die sich als Differenz zu "Insgesamt" erschlieen, sind zu vermeiden.
*** Beispiel: Sie erzeugen eine "Insgesamt"-Tabelle und eine Tabelle "Mnnlich".
*** Die Restgre/Differenz ist "Weiblich" und muss mit ausgegeben werden.

*** Output Nr.5 a-c: Hufigkeit des hchsten allgemeinen Schulabschluss nach gesamt/mnnlich/weiblich. 

TITLE "Output Nr.5a: Hufigkeit des hchsten allgemeinen Schulabschluss nach Gesamt".
FREQUENCIES VAR = EF310.
EXECUTE.

TITLE "Output Nr.5b: Hufigkeit des hchsten allgemeinen Schulabschluss nach mnnlich".
TEMPORARY. 
SELECT IF EF46 = 1.
FREQUENCIES VAR = EF310.
EXECUTE.

TITLE "Output Nr.5c: Hufigkeit des hchsten allgemeinen Schulabschluss nach weiblich".
TEMPORARY. 
SELECT IF EF46 = 2.
FREQUENCIES VAR = EF310.
EXECUTE.


*** Hinweis: Alternativ kann fr diese Art der Auswertung auch eine Kreuztabelle ohne vorherige Fallauswahl 
*** verwendet werden. Durch die Verwendung einer Kreuztabelle werden Restgren direkt vermieden.


*******************************************************************************************************************.
*** c. Ausgabe deskriptiver Kennzahlen ***

*** Aus Geheimhaltungsgrnden sind Minima und Maxima metrischer Variablen zu unterdrcken.

*** Output Nr. 6: Anzahl, Mittelwert und Standardabweichung (STD) des Alters aller ledigen Personen.

TITLE "Output Nr. 6: Anzahl, Mittelwert und STD des Alters aller ledigen Personen".
TEMPORARY.
SELECT IF EF49 = 1.
SUMMARIZE EF44 /CELLS = count mean stddev.


*** Hinweis: Bei wirtschaftsstatistischen Daten ist bei der Ausgabe von deskriptiven Kennzahlen fr die 
*** Geheimhaltungsprfung das Maximum, der zweitgrte Wert und die Gesamtsumme der Variablen 
*** (z.B. Umsatz, Einknfte) mit auszugeben.


*******************************************************************************************************************.
*** d. Auswertungen von Dummy-Variablen ***

*** Zustzlich zum Sum-Befehl ist die Hufigkeitstabelle auszugeben, da die Fallzahl der Merkmalsausprgung 
*** fr die Geheimhaltungsprfung bentigt wird.
 
*** Output Nr. 7a-b: Anzahl, Mittelwert und Standardabweichung (STD) des Geschlechtes 
***                         aller ber 65-Jhrigen (EF44 > 65).

TITLE "Output Nr. 7a: Anzahl, Mittelwert und STD des Geschlechtes aller ber 65-Jhrigen".
TEMPORARY.
SELECT IF EF44 > 65.
SUMMARIZE EF46  /CELLS= count mean stddev.

TITLE "Output Nr. 7b: Hufigkeitsauszhlung des Geschlechts aller ber 65-Jhrigen".
TEMPORARY.
SELECT IF EF44 > 65.
FREQUENCIES VAR = EF46.


*******************************************************************************************************************.
*** e. Ausgabe von Wertetabellen ***

*** Bei der Erstellung von Wertetabellen ist stets die zugrundeliegende Fallzahl mit anzugeben.

*** Erstellen einer benutzerdefinierten Tabelle mit Anzahl, Mittelwert und gltige Hufigkeit (N) des Alters (EF44) 
*** je Ausprgung Familienstand (EF49)

*** Output Nr. 8: Kreuztabelle Alter und Familienstand.

CTABLES
  /VLABELS VARIABLES=EF49 EF44 DISPLAY = DEFAULT
  /TABLE EF44 [MEAN, VALIDN F40.0] BY EF49
  /CATEGORIES VARIABLES = EF49 ORDER = A KEY = VALUE EMPTY = EXCLUDE
  /TITLES
   TITLE = 'Output Nr. 8: Kreuztabelle Alter und Familienstand'.


*******************************************************************************************************************.

*** Die vorliegende Mustersyntax stellt ein Beispiel fr eine Erstsyntax dar. Wenn in den folgenden Syntaxen 
*** Auswertungen gemacht werden, die einen inhaltlichen Bezug zu bereits erstellten Ergebnissen haben, sind die 
*** Bezge zu den entsprechenden vorherigen Syntaxen sowohl bei der Datenaufbereitung als auch bei der Auswertung in 
*** einem Kommentar kenntlich zu machen.



*******************************************************************************************************************.
*** III. Speichern der Outputdatei als spv- und xls-Dokument.
*******************************************************************************************************************.

OUTPUT SAVE OUTFILE = !OUTPUTPFAD+!OUTPUTNAME+".spv".  

OUTPUT EXPORT
 /CONTENTS EXPORT = VISIBLE
 /XLS DOCUMENTFILE = !OUTPUTPFAD+!OUTPUTNAME
 OPERATION = CREATEFILE
 SHEET = 'Tabelle1'.








